Coerce a tableby object to a data.frame.
Usage
# S3 method for class 'tableby'
as.data.frame(x, ..., labelTranslations = NULL, list.ok = FALSE)Arguments
- x
A
tablebyobject.- ...
Arguments to pass to
tableby.control.- labelTranslations
A named list (or vector) where the name is the label in the output to be replaced in the pretty rendering by the character string value for the named element of the list, e.g.,
list(age = "Age(Years)", meansd = "Mean(SD)").- list.ok
If the object has multiple by-variables, is it okay to return a list of data.frames instead of a single data.frame? If
FALSEbut there are multiple by-variables, a warning is issued.