A collection of functions that may help users create custom functions that are formatted correctly.
Usage
tbfmt(x, digits = NULL, digits.count = NULL, digits.pct = NULL, ...)
as.tbstat(
x,
oldClass = NULL,
fmt = "{y}",
which.count = 0L,
which.pct = 0L,
...
)
as.tbstat_multirow(x)Arguments
- x
Usually a vector.
- digits, digits.pct, digits.count
Digits specifications
- ...
arguments to pass to
as.tbstat.- oldClass
class(es) to add to the resulting object.
- fmt
A
gluestring, where the object is exposed as the variablex, and a default-formatted version (usingtbfmt) exposed as the variabley.digits,digits.count, anddigits.pctare also exposed.- which.count
Which statistics are counts? The default is 0, indicating that none are.
- which.pct
Which statistics are percents? The default is 0, indicating that none are.